@@ -25,10 +25,6 @@ Utilities for working with :pep:`508` requirements.
 #  OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
 #  OR OTHER DEALINGS IN THE SOFTWARE.
 #
-#  check_dependencies based on https://stackoverflow.com/a/29044693/3092681
-#  Copyright © 2015 TehTechGuy
-#  Licensed under CC-BY-SA
-#
 
 # stdlib
 import copy
@@ -37,7 +33,6 @@ from abc import ABC
 from typing import Any, Callable, Dict, Iterable, Iterator, List, Optional, Set, Tuple, Union, cast, overload
 
 # 3rd party
-import deprecation_alias
 import dist_meta
 import dom_toml
 from domdf_python_tools.doctools import prettify_docstrings
@@ -51,7 +46,7 @@ from packaging.specifiers import BaseSpecifier, Specifier, SpecifierSet
 from typing_extensions import Literal
 
 # this package
-from shippinglabel import __version__, normalize
+from shippinglabel import normalize
 
 __all__ = [
 		"ComparableRequirement",
@@ -60,7 +55,6 @@ __all__ = [
 		"read_requirements",
 		"RequirementsManager",
 		"list_requirements",
-		"check_dependencies",
 		"parse_requirements",
 		"parse_pyproject_dependencies",
 		"parse_pyproject_extras",
@@ -575,7 +569,7 @@ class RequirementsManager(ABC):
 
 
 def marker_environment(extra: str) -> Dict[str, str]:
-	env: Dict[str, str] = default_environment()
+	env: Dict[str, str] = default_environment()  # type: ignore[assignment]
 	env["extra"] = extra
 	return env
 
@@ -639,39 +633,6 @@ def list_requirements(
 				yield deps
 
 
-@deprecation_alias.deprecated(deprecated_in="1.6.0", removed_in="2.0", current_version=__version__)
-def check_dependencies(dependencies: Iterable[str], prt: bool = True) -> List[str]:
-	"""
-	Check whether one or more dependencies are available to be imported.
-
-	:param dependencies: The list of dependencies to check the availability of.
-	:param prt: Whether the status should be printed to the terminal.
-
-	:return: A list of any missing modules.
-	"""
-
-	# stdlib
-	from pkgutil import iter_modules
-
-	modules = {x[1] for x in iter_modules()}
-	missing_modules = []
-
-	for requirement in dependencies:
-		if requirement not in modules:
-			missing_modules.append(requirement)
-
-	if prt:
-		if len(missing_modules) == 0:
-			print("All modules installed")
-		else:
-			print("The following modules are missing:")
-			print(missing_modules)
-			print("Please check the documentation.")
-		print('')
-
-	return missing_modules
-
-
 def parse_pyproject_dependencies(
 		pyproject_file: PathLike,
 		flavour: Literal["pep621", "flit", "auto"] = "auto",
